aboutsummaryrefslogtreecommitdiffstats
path: root/parameter/SelectionCriterionType.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parameter/SelectionCriterionType.cpp')
-rw-r--r--parameter/SelectionCriterionType.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/parameter/SelectionCriterionType.cpp b/parameter/SelectionCriterionType.cpp
index 9bc07a4..3e9cc80 100644
--- a/parameter/SelectionCriterionType.cpp
+++ b/parameter/SelectionCriterionType.cpp
@@ -32,7 +32,7 @@
#define base CElement
-const string CSelectionCriterionType::_strDelimiter = "|";
+const std::string CSelectionCriterionType::_strDelimiter = "|";
CSelectionCriterionType::CSelectionCriterionType(bool bIsInclusive) : _bInclusive(bIsInclusive)
{
@@ -43,13 +43,13 @@ CSelectionCriterionType::CSelectionCriterionType(bool bIsInclusive) : _bInclusiv
}
}
-string CSelectionCriterionType::getKind() const
+std::string CSelectionCriterionType::getKind() const
{
return "SelectionCriterionType";
}
// From ISelectionCriterionTypeInterface
-bool CSelectionCriterionType::addValuePair(int iValue, const string& strValue)
+bool CSelectionCriterionType::addValuePair(int iValue, const std::string& strValue)
{
// Check 1 bit set only for inclusive types
if (_bInclusive && (!iValue || (iValue & (iValue - 1)))) {
@@ -71,17 +71,17 @@ bool CSelectionCriterionType::addValuePair(int iValue, const string& strValue)
return true;
}
-bool CSelectionCriterionType::getNumericalValue(const string& strValue, int& iValue) const
+bool CSelectionCriterionType::getNumericalValue(const std::string& strValue, int& iValue) const
{
if (_bInclusive) {
Tokenizer tok(strValue, _strDelimiter);
- vector<string> astrValues = tok.split();
+ std::vector<std::string> astrValues = tok.split();
uint32_t uiNbValues = astrValues.size();
int iResult = 0;
uint32_t uiValueIndex;
// Looping on each string delimited by "|" token and adding the associated value
for (uiValueIndex = 0; uiValueIndex < uiNbValues; uiValueIndex++) {
if (!getAtomicNumericalValue(astrValues[uiValueIndex], iResult)) {
@@ -95,7 +95,7 @@ bool CSelectionCriterionType::getNumericalValue(const string& strValue, int& iVa
return getAtomicNumericalValue(strValue, iValue);
}
-bool CSelectionCriterionType::getAtomicNumericalValue(const string& strValue, int& iValue) const
+bool CSelectionCriterionType::getAtomicNumericalValue(const std::string& strValue, int& iValue) const
{
NumToLitMapConstIt it = _numToLitMap.find(strValue);
@@ -108,7 +108,7 @@ bool CSelectionCriterionType::getAtomicNumericalValue(const string& strValue, in
return false;
}
-bool CSelectionCriterionType::getLiteralValue(int iValue, string& strValue) const
+bool CSelectionCriterionType::getLiteralValue(int iValue, std::string& strValue) const
{
NumToLitMapConstIt it;
@@ -130,9 +130,9 @@ bool CSelectionCriterionType::isTypeInclusive() const
}
// Value list
-string CSelectionCriterionType::listPossibleValues() const
+std::string CSelectionCriterionType::listPossibleValues() const
{
- string strValueList = "{";
+ std::string strValueList = "{";
// Get comma seprated list of values
NumToLitMapConstIt it;
@@ -155,9 +155,9 @@ string CSelectionCriterionType::listPossibleValues() const
}
// Formatted state
-string CSelectionCriterionType::getFormattedState(int iValue) const
+std::string CSelectionCriterionType::getFormattedState(int iValue) const
{
- string strFormattedState;
+ std::string strFormattedState;
if (_bInclusive) {
@@ -176,7 +176,7 @@ string CSelectionCriterionType::getFormattedState(int iValue) const
}
// Simple translation
- string strSingleValue;
+ std::string strSingleValue;
getLiteralValue(iSingleBitValue, strSingleValue);
@@ -71,17 +71,17 @@ bool CSelectionCriterionType::addValuePair(int iValue, const string& strValue)
int iResult = 0;
uint32_t uiValueIndex;
- // Looping on each string delimited by "|" token and adding the associated value
+ // Looping on each std::string delimited by "|" token and adding the associated value
for (uiValueIndex = 0; uiValueIndex < uiNbValues; uiValueIndex++) {
if (!getAtomicNumericalValue(astrValues[uiValueIndex], iResult)) {